@@ -38,6 +38,10 @@ class NotFoundError(Error):
     pass
 
 
+class EndPointError(Error):
+    pass
+
+
 class BaseAPI(object):
     """
         Basic api class for
@@ -46,12 +50,21 @@ class BaseAPI(object):
     end_point = "https://api.digitalocean.com/v2/"
 
     def __init__(self, *args, **kwargs):
-        self.token = ""
-        self.end_point = "https://api.digitalocean.com/v2/"
+        self.token = os.getenv("DIGITALOCEAN_ACCESS_TOKEN", "")
+        self.end_point = os.getenv("DIGITALOCEAN_END_POINT", "https://api.digitalocean.com/v2/")
         self._log = logging.getLogger(__name__)
 
+        self._session = requests.Session()
+
         for attr in kwargs.keys():
             setattr(self, attr, kwargs[attr])
+        
+        parsed_url = urlparse.urlparse(self.end_point)
+        if not parsed_url.scheme or not parsed_url.netloc:
+            raise EndPointError("Provided end point is not a valid URL. Please use a valid URL")
+
+        if not parsed_url.path:
+            self.end_point += '/'
 
     def __getstate__(self):
         state = self.__dict__.copy()
@@ -83,12 +96,12 @@ class BaseAPI(object):
         identity = lambda x: x
         json_dumps = lambda x: json.dumps(x)
         lookup = {
-            GET: (requests.get, {}, 'params', identity),
-            POST: (requests.post, {'Content-type': 'application/json'}, 'data',
+            GET: (self._session.get, {'Content-type': 'application/json'}, 'params', identity),
+            POST: (self._session.post, {'Content-type': 'application/json'}, 'data',
                    json_dumps),
-            PUT: (requests.put, {'Content-type': 'application/json'}, 'data',
+            PUT: (self._session.put, {'Content-type': 'application/json'}, 'data',
                   json_dumps),
-            DELETE: (requests.delete,
+            DELETE: (self._session.delete,
                      {'content-type': 'application/json'},
                      'data', json_dumps),
         }
